"""Initialize seed variables."""
__all__ = ['__author__', '__description__', '__version__']
__version__ = '1.1.0'
__author__ = 'Lacides Miranda'
__description__ = 'Seed Plugin scaffold for Datoso'
__prefix__ = 'Enhanced'
